import os
import pygame
import random
from pygame.locals import *
if not pygame.font: print 'Warning, fonts disabled'
if not pygame.mixer: print 'Warning, sound disabled'
scrollx = 0
times_through = 1
def load_image(name, colorkey=None):
    fullname = os.path.join('Images', name)
    try:
        image = pygame.image.load(fullname)
    except pygame.error, message:
        print 'Cannot load image:', fullname
        raise SystemExit, message
    image = image.convert()
    if colorkey is not None:
        if colorkey is -1:
            colorkey = image.get_at((0,0))
        image.set_colorkey(colorkey, RLEACCEL)
    return image, image.get_rect()


def load_animation(names, colorkey=None):
    images = []
    lastrect = None
    for name in names:
        image, rect = load_image(name, colorkey)
        images.append(image)
        if lastrect:
            if lastrect != rect:
                raise pygame.error("All images must be the same size.")
    return images, rect


def load_sound(name):
    class NoneSound:
        def play(self): pass
    if not pygame.mixer or not pygame.mixer.get_init():
        return NoneSound()
    fullname = os.path.join('Sounds', name)
    try:
        sound = pygame.mixer.Sound(fullname)
    except pygame.error, message:
        print 'Cannot load sound:', fullname
        raise SystemExit, message
    return sound


pygame.init()
screen = pygame.display.set_mode((900, 900))
def gravity(being):
    if pygame.sprite.spritecollide(being, floor_,0):
        being.rect.move_ip(0,-1)
    else:
        being.rect.move_ip(0,1)

class Pause(pygame.sprite.Sprite):


    def __init__(self, top, left):
        pygame.sprite.Sprite.__init__(self)
        self.image, self.rect = load_image('pause.bmp', -1)
        self.rect = (top,left)
    def update(self):
        pass
    
    
class Instuctions(pygame.sprite.Sprite):

    def __init__(self, top, left):
        pygame.sprite.Sprite.__init__(self)
        self.image, self.rect = load_image('KeyBoardImage.png')
        self.rect.top = top
        self.rect.left = left
    def update(self):
        pass
    
    
class Ceiling(pygame.sprite.Sprite):


    def __init__(self, top, left):
        pygame.sprite.Sprite.__init__(self)
        self.image, self.rect = load_image('LongFloor.png')
        self.rect.top = top
        self.rect.left = left

    def update(self):
        global ninja
        if  ninja.mode == Ninja.MODE_RUNNINGJUMP:
            self.rect.move_ip(((-scrollx)+200*0),0)
        if  ninja.mode == Ninja.MODE_RUNNING:
            self.rect.move_ip(((-scrollx)+200*0),0)    

class Floor(pygame.sprite.Sprite):
    """ This class represents the floor we walk on """
    def __init__(self, top, left):
        pygame.sprite.Sprite.__init__(self)
        self.image, self.rect = load_image('LongFloor.png')
        self.rect.top = top
        self.rect.left = left

    def update(self):
        global ninja
        if  ninja.mode == Ninja.MODE_RUNNINGJUMP:
            self.rect.move_ip(((-scrollx)+200*0),0)
        if  ninja.mode == Ninja.MODE_RUNNING:
            self.rect.move_ip(((-scrollx)+200*0),0)
            
class PlatformCeiling(pygame.sprite.Sprite):
    def __init__(self, top, left):
        pygame.sprite.Sprite.__init__(self)
        self.image, self.rect = load_image('PlatformFloor.png')
        self.rect.top = top
        self.rect.left = left

    def update(self):
        global ninja
        if  ninja.mode == Ninja.MODE_RUNNINGJUMP:
            self.rect.move_ip(((-scrollx)+200*0),0)
        if  ninja.mode == Ninja.MODE_RUNNING:
            self.rect.move_ip(((-scrollx)+200*0),0)\
                
            
class Platform(pygame.sprite.Sprite):
    def __init__(self, top, left):
        pygame.sprite.Sprite.__init__(self)
        self.image, self.rect = load_image('Platform.png')
        self.rect.top = top
        self.rect.left = left

    def update(self):
        global ninja
        if  ninja.mode == Ninja.MODE_RUNNINGJUMP:
            self.rect.move_ip(((-scrollx)+200*0),0)
        if  ninja.mode == Ninja.MODE_RUNNING:
            self.rect.move_ip(((-scrollx)+200*0),0)
            

class MovingPlatform(pygame.sprite.Sprite):
    def __init__(self, top, left):
        pygame.sprite.Sprite.__init__(self)
        self.image, self.rect = load_image('Platform.png')
        self.rect.top = top
        self.rect.left = left
        self.move = 0
        self.done_moving = 600
        self.scrollx = 1
    def update(self):
        global ninja
        if self.move == 1:
            if self.done_moving > 0:
                self.rect.move_ip(((self.scrollx)+200*0),0)
                self.done_moving -= 1
        if pygame.sprite.spritecollide(self, ninja_, 0):
            self.move = 1
        if  ninja.mode == Ninja.MODE_RUNNINGJUMP:
            self.rect.move_ip(((-scrollx)+200*0),0)
        if  ninja.mode == Ninja.MODE_RUNNING:
            self.rect.move_ip(((-scrollx)+200*0),0)
class Wall_left(pygame.sprite.Sprite):
    def __init__(self, top, left):
        pygame.sprite.Sprite.__init__(self)
        self.image, self.rect = load_image('TestWall.png',-1)
        self.rect.bottom = top
        self.rect.left = left

    def update(self):
        global ninja
        if pygame.sprite.spritecollide(self, ninja_, 0):
            global bosscat
            bosscat.firemissle = 1
        if  ninja.mode == Ninja.MODE_RUNNINGJUMP:
            self.rect.move_ip(((-scrollx)+200*0),0)
        if  ninja.mode == Ninja.MODE_RUNNING: 
            self.rect.move_ip(((-scrollx)+200*0),0)
            
            
class Ninja(pygame.sprite.Sprite):
    MODE_ATTACKING = 1
    MODE_RUNNING = 2
    MODE_STANCING = 3
    MODE_JUMPING = 4
    MODE_RUNNINGJUMP = 5
    MODE_STOPPING = 6
    
    MAX_JUMP_HEIGHT = -75  #Max height Ninja can jump  (up is negative along the y axis)
    JUMP_UPWARD_ACCELERATION = -0.5 # How fast we move up

    def __init__(self, top, left):
        pygame.sprite.Sprite.__init__(self)
        self.death, self.rect = load_animation(["NinjaDeath1.png",
                                                "NinjaDeath2.png",
                                                "NinjaDeath3.png",
                                                "NinjaDeath4.png",
                                                "NinjaDeath5.png",
                                                "NinjaDeath6.png",
                                                "NinjaDeath7.png",
                                                "NinjaDeath8.png",
                                                "NinjaDeath9.png",
                                                "NinjaDeath10.png",],(0,255,6))
        self.stance, self.rect = load_animation(["NinjaStance1.png",
                                                 "NinjaStance2.png",
                                                 "NinjaStance3.png",
                                                 "NinjaStance4.png",],(0,255,6))
        self.attack, self.rect = load_animation(["NinjaPunch1.png",
                                                 "NinjaPunch2.png",
                                                 "NinjaPunch3.png",
                                                 "NinjaPunch4.png",
                                                 "NinjaPunch3.png",
                                                 "NinjaPunch2.png",
                                                 "NinjaPunch1.png",],(0,255,6))
        self.runjump, self.rect = load_animation(["NinjaRun3.png",],(0,255,6))
        self.jump, self.rect = load_animation(["NinjaJump.png",],(0,255,6))
        self.run, self.rect = load_animation(["NinjaRun1.png",
                                              "NinjaRun2.png",
                                              "NinjaRun3.png",
                                              "NinjaRun4.png",
                                              "NinjaRun5.png",
                                              "NinjaRun6.png",],(0,255,6))
        self.stanceimage = 0
        self.attackimage = 0
        self.runimage = 0
        self.image = self.stance[self.stanceimage]
        self.delay = 1
        self.update_round = 0
        self.rect.center = (top,left)
        self.vx = 0
        self.attacking = 0
        self.jump_up = 50
        self.jump_down = 25
        self.ay = Ninja.JUMP_UPWARD_ACCELERATION
        self.vy = 0
        self.in_air = 0
        self.mode = Ninja.MODE_STANCING
        self.height = 0
        self.killing = 0
        self.hp = 100
        self.direction = 0.1
        self.ax = self.direction
        self.imagedirection = 0
        


    def update(self):
        if self.hp <= 0:
            print "YOU LOSE!!!!!!!!!!!!!!!"
            raise GameOverException
        self.ax = self.direction
        for a_mushroom in bigmushrooms_:
            if self.attacking == 0:
                if pygame.sprite.collide_rect(a_mushroom, self):
                    if a_mushroom.dead == 0:
                        self.hp -= 1
                    a_mushroom.die()
        for a_minion in minion_:
            if self.attacking == 0:
                if pygame.sprite.collide_rect(a_minion, self):
                        if a_minion.dead == 0:
                            self.hp -= 1
                        a_minion.die()
        if not self.in_air == 1:
            gravity(self)
        global scrollx
        self.update_round += 1
        if self.mode == Ninja.MODE_JUMPING or self.mode == Ninja.MODE_RUNNINGJUMP:
            self.vy += self.ay
            self.height += self.vy
            if self.height > 1 or self.height < (-1):
                if pygame.sprite.spritecollide(self, floor_,0):
                    self.in_air = 0
                    self.height = 0
                    self.vy = 0
                    if self.mode == Ninja.MODE_JUMPING:
                        self.in_air = 0
                        self.change_mode(Ninja.MODE_STANCING)
                    else:
                        self.in_air = 0
                        self.change_mode(Ninja.MODE_RUNNING)

            self.rect.move_ip(0, self.vy)
            if self.height <= Ninja.MAX_JUMP_HEIGHT:
                self.ay = abs(self.ay)
            if self.height >= 0:
                self.height = 0
                self.vy = 0
                if self.mode == Ninja.MODE_JUMPING:
                    self.in_air = 0
                    self.change_mode(Ninja.MODE_STANCING)
                else:
                    self.in_air = 0
                    self.change_mode(Ninja.MODE_RUNNING)

        if self.mode == Ninja.MODE_STANCING and self.update_round == 15:
            self.in_air == 0
            self.update_round = 1
            self.vx = 0
            if self.stanceimage == 3:
                self.stanceimage = 1
            self.stanceimage += 1
            self.image = self.stance[self.stanceimage]
            if self.ax < 0:
                self.image = pygame.transform.flip(self.image, 1, 0)
        if self.mode == Ninja.MODE_RUNNING and self.update_round == 15:
            self.in_air == 0
            self.update_round = 1
            if scrollx < 5 and self.ax < 0:
                scrollx += self.vx
            if scrollx > -5 and self.ax > 0:
                scrollx += self.vx
            if self.runimage == 5:
                self.runimage = (-1)
            self.runimage += 1
            self.image = self.run[self.runimage]
            if self.ax < 0:
                self.image = pygame.transform.flip(self.image, 1, 0)
            self.vx += self.ax
            if self.vx > 1:
                self.vx=1
        if self.attacking == 1 and self.update_round == 10 :           
            for a_minion in minion_:
                if self.killing == 0:
                    if pygame.sprite.collide_rect(a_minion, self):
                        a_minion.die()
            self.in_air == 0
            self.update_round = 1
            self.attackimage += 1
            if self.attackimage == 7:
                self.attacking = 0
                self.killing = 0
                if self.vx <= 0:
                    self.ax = 0.1
                    self.vx = 0
                    self.change_mode(Ninja.MODE_STANCING)
                self.attackimage = 6
            self.image = self.attack[self.attackimage]
            if self.ax < 0:
                self.image = pygame.transform.flip(self.image, 1, 0)

    def change_mode(self, newmode):
        """ Change the mode, if it is different.  And if we change it reset self.update_round """
        if self.mode != newmode:
            self.update_round = 0
            self.mode = newmode
            if self.mode == Ninja.MODE_JUMPING:
                self.image = self.jump[0]
                if self.ax < 0:
                    self.image = pygame.transform.flip(self.image, 1, 0)
            elif self.mode == Ninja.MODE_RUNNINGJUMP:
                self.image = self.runjump[0]
                if self.ax < 0:
                    self.image = pygame.transform.flip(self.image, 1, 0)
            
    def handle_keydown(self, event):
        if event.key == K_w:
            self.ay = Ninja.JUMP_UPWARD_ACCELERATION
            if self.mode == Ninja.MODE_RUNNING:
                self.in_air = 1
                self.change_mode(Ninja.MODE_RUNNINGJUMP)
                self.rect.move_ip(0,-4)
            else:
                self.in_air = 1
                self.change_mode(Ninja.MODE_JUMPING)
                self.rect.move_ip(0,-4)
        elif event.key == K_d:
            if not self.in_air:
                global scrollx
                scrollx = 0
                self.vx = 0.1
                self.direction = 0.1
        
                self.change_mode(Ninja.MODE_RUNNING)

        elif event.key == K_a:
            if not self.in_air:
                global scrollx
                scrollx = 0
                self.vx = 0.1
                self.direction = -0.1
                self.change_mode(Ninja.MODE_RUNNING)
        elif event.key == K_l:
            if not self.attacking:
                self.killing = 0
                self.attacking = 1
                self.attackimage = 0

    def handle_keyup(self, event):
        if event.key == K_d:
            self.vx = 0
            if not self.mode == Ninja.MODE_JUMPING:
                self.change_mode(Ninja.MODE_STANCING)
        elif event.key == K_a:
            self.vx = 0
            if not self.mode == Ninja.MODE_JUMPING:
                self.change_mode(Ninja.MODE_STANCING)

ninja_ = None

class Minion(pygame.sprite.Sprite):
    def __init__(self, top, left ,hive):
        pygame.sprite.Sprite.__init__(self)
        self.death, self.rect = load_animation(["MinionDeath.png",],(0,0,255))
        self.walk, self.rect = load_animation(["MinionWalk1.png",
                                               "MinionWalk2.png",],(0,0,255))
        self.walkimage = 0
        self.image = self.walk[self.walkimage]
        self.direction = -1
        self.patrol = 20
        self.rect.top = top
        self.rect.left = left
        self.update_round=0
        self.my_hive = hive
        self.dead = 0
    def update(self):
        if self.rect.top < 0:
            self.dead = 1
        if pygame.sprite.spritecollide(self, wall_, 0):
            self.rect.move_ip(1,0)
        if  ninja.mode == Ninja.MODE_RUNNINGJUMP:
            self.rect.move_ip(((-scrollx)+200*0),0)
        if  ninja.mode == Ninja.MODE_RUNNING:
            self.rect.move_ip(((-scrollx)+200*0),0)
        self.update_round+=1
        if self.dead == 1:
            self.die()
        if self.dead == 0:
            if random.randrange(0,100) < 50:
                self.rect.move_ip(random.randrange(-5,5),0)
            self.update_round+=1
            gravity(self)
            self.image = self.walk[self.walkimage]
            if ninja.rect.midtop > self.rect.midtop:
                self.rect.move_ip(1,0)
            else:
                self.rect.move_ip(-1,0)        
            if self.update_round==15:
                self.update_round=0
                if self.walkimage == 0:
                    self.walkimage = 1
                else:
                    self.walkimage = 0

    def die(self):
        self.image = self.death[0]
        if self.update_round > 15:
            self.update_round=0
        if self.dead == 1 and self.update_round == 15:
            self.my_hive.number_of_minions -= 1
            self.kill()
        self.dead = 1
        
minion_ = None
class MissleRight(pygame.sprite.Sprite):
    def __init__(self, top, left):
        pygame.sprite.Sprite.__init__(self)
        self.explosion, self.rect = load_animation(["explosion1.png",
                                               "explosion2.png",
                                               "explosion3.png",
                                               "explosion4.png",
                                               "explosion5.png",
                                               "explosion6.png",
                                               "explosion7.png",],(0,255,0))
        self.walk, self.rect = load_animation(["Missle1.png",
                                           "Missle2.png",],(255,255,255))
        self.update_round = 0  
        self.missleimage = 0
        self.explodeimage = 0
        self.image = self.walk[self.missleimage]
        self.dead = 0
        self.rect.top = top
        self.rect.left = left
    def update(self):
        if  ninja.mode == Ninja.MODE_RUNNINGJUMP:
                self.rect.move_ip(((-scrollx)),0)
        if  ninja.mode == Ninja.MODE_RUNNING:
                self.rect.move_ip(((-scrollx)),0)
        self.update_round += 1
        if self.dead == 1:
            self.explode()
            
        if self.dead == 0:
            if self.update_round == 10:
                self.update_round = 0 
                if self.missleimage == 0:
                    self.missleimage = 1
                else:
                    self.missleimage = 0
                self.image = self.walk[self.missleimage]
            self.rect.move_ip(4,0)
            if pygame.sprite.spritecollide(self, ninja_,0):
                self.dead = 1
                if pygame.sprite.collide_rect(ninja, self):
                    ninja.hp -= 3
                self.explode()
            
    def explode(self):
        if self.update_round == 10:
            self.update_round = 0
            self.image = self.explosion[self.explodeimage]
            self.explodeimage += 1
            if self.explodeimage == len(self.explosion):
                self.kill()
        
class BossCat(pygame.sprite.Sprite):
    def __init__(self, top, left):
        pygame.sprite.Sprite.__init__(self)
        self.prepare, self.rect = load_image("BossCatAttackPrepare.png",(0,255,0))
        self.ready,  self.rect = load_image("BossCatAttackReady.png",(0,255,0))
        self.stance,  self.rect = load_animation(["BossCatStance1.png",
                                                  "BossCatStance2.png"],(0,255,0))
        self.direction = 1
        self.hp = 1
        self.firemissle = 0
        self.update_round = 0
        self.update_round2 = 0
        self.stanceimage = 0
        self.image = self.stance[self.stanceimage]
        self.rect.center = (top,left)
        self.dead = 0\
        
    def update(self):
        if pygame.sprite.collide_rect(self, ninja) and ninja.attacking == 1:
            self.hp = (self.hp - 1)
        if self.hp == 0:
            floor_.empty()
            ninja_.empty()
            bigmushrooms_.empty()
            minion_.empty()
            missles_.empty()
            bosscat_.empty()
            wall_.empty()
            setup_game()
        if (ninja.rect.left - self.rect.left)<1000:
            self.firemissle = 1
        if  ninja.mode == Ninja.MODE_RUNNINGJUMP:
                self.rect.move_ip(((-scrollx)),0)
        if  ninja.mode == Ninja.MODE_RUNNING:
                self.rect.move_ip(((-scrollx)),0)
        self.update_round += 1
        self.update_round2 += 1
        if self.dead == 1:
            self.kill()

            if self.update_round % 10 == 0:
                pass
            if self.update_round % 15 == 0:
                pass
        if self.dead == 0:
            if self.firemissle == 1:
                if self.update_round2 == 50:
                    self.update_round2 = 0
                    self.image = self.prepare
                    if ninja.rect.midtop > self.rect.midtop:
                        self.create_missleright()
                    else:
                        self.create_missleleft()
            if self.update_round == 15:
                self.update_round = 0 
                if self.stanceimage == 0:
                    self.stanceimage = 1
                else:
                    self.stanceimage = 0
                self.image = self.stance[self.stanceimage]
    def create_missleleft(self):
        global missles_
        self.newminion = MissleLeft(self.rect.top, self.rect.left)
        missles_.add(self.newminion)    
    def create_missleright(self):
        global missles_
        self.newminion = MissleRight(self.rect.top, self.rect.left)
        missles_.add(self.newminion)    
class MissleLeft(pygame.sprite.Sprite):
    def __init__(self, top, left):
        pygame.sprite.Sprite.__init__(self)
        self.explosion, self.rect = load_animation(["explosion1.png",
                                               "explosion2.png",
                                               "explosion3.png",
                                               "explosion4.png",
                                               "explosion5.png",
                                               "explosion6.png",
                                               "explosion7.png",],(0,255,0))
        self.walk, self.rect = load_animation(["Missle3.png",
                                           "Missle4.png",],(255,255,255))
        self.update_round = 0  
        self.missleimage = 0
        self.explodeimage = 0
        self.image = self.walk[self.missleimage]
        self.dead = 0
        self.rect.top = top
        self.rect.left = left
    def update(self):
        if  ninja.mode == Ninja.MODE_RUNNINGJUMP:
                self.rect.move_ip(((-scrollx)),0)
        if  ninja.mode == Ninja.MODE_RUNNING:
                self.rect.move_ip(((-scrollx)),0)
        self.update_round += 1
        if self.dead == 1:
            self.explode()
            
        if self.dead == 0:
            if self.update_round == 10:
                self.update_round = 0 
                if self.missleimage == 0:
                    self.missleimage = 1
                else:
                    self.missleimage = 0
                self.image = self.walk[self.missleimage]
            self.rect.move_ip(-4,0)
            if pygame.sprite.spritecollide(self, ninja_,0):
                self.dead = 1
                if pygame.sprite.collide_rect(ninja, self):
                    ninja.hp -= 3
                self.explode()
            
    def explode(self):
        if self.update_round == 10:
            self.update_round = 0
            self.image = self.explosion[self.explodeimage]
            self.explodeimage += 1
            if self.explodeimage == len(self.explosion):
                self.kill()    
class BigMushroom(pygame.sprite.Sprite):
    def __init__(self, top, left):
        pygame.sprite.Sprite.__init__(self)
        self.death,self.rect = load_image("BigMushroomDead.png",(0,0,255))
        self.walk, self.rect = load_animation(["BigMushroomStance1.png",
                                               "BigMushroomStance2.png",
                                               "BigMushroomStance3.png",
                                               "BigMushroomStance4.png"],(0,0,255))
        self.stanceimage = 0
        self.image = self.walk[self.stanceimage]
        self.update_round = 1
        self.rect.top = top
        self.rect.left = left
        self.number_of_minions = 0
        self.wait = 0
        self.dead = 0
        self.hp = 7
    def update(self):
        if  ninja.mode == Ninja.MODE_RUNNINGJUMP:
                self.rect.move_ip(((-scrollx)+200*0),0)
        if  ninja.mode == Ninja.MODE_RUNNING:
                self.rect.move_ip(((-scrollx)+200*0),0)
        self.update_round += 1
        if self.dead == 1:
            self.die()
        if self.dead == 0:
            if self.number_of_minions < 4:
                self.wait += 1
                if self.wait == 150:
                    self.wait = 0
                    self.create_minion()
            global ninja
            if self.update_round == 15:
                self.update_round = 1
                self.stanceimage +=1
                self.image = self.walk[self.stanceimage]
            if self.stanceimage == 3:
                self.stanceimage = -1
    def create_minion(self):
        self.number_of_minions += 1
        global minion_
        self.newminion = Minion(self.rect.top, self.rect.left, self)
        minion_.add(self.newminion)

    def die(self):
        self.dead = 1
        self.image = self.death
        if self.update_round > 15:
            self.update_round=0
        if self.dead == 1 and self.update_round == 15:
            self.kill()
class GameOverException(Exception):
    pass

def setup_game():
    
    font = pygame.font.Font(None, 36)
    text_=font.render(("Life"), 1, (10, 10, 10), (255,255,255))
    
    
    global background
    background = pygame.Surface(screen.get_size())
    background = background.convert()
    background.fill((255, 255, 255))
    screen.blit(background, (0, 0))
    pygame.display.flip()
    
    
    global clock
    clock = pygame.time.Clock()
    
    
    pause=Pause(300,300)
    pause_ = pygame.sprite.RenderPlain(pause)
    global ninja , ninja_ , bigmushrooms_ , missles_ , minion_,floor_,bosscat_,wall_,bigmushroom,bosscat
    ninja=Ninja(450,835)
    ninja_ = pygame.sprite.RenderPlain(ninja)
    wall_ = pygame.sprite.RenderPlain(Wall_left(850,8000))
    bigmushroom = BigMushroom(785,5500)
    pause_ = pygame.sprite.RenderPlain(pause)
    bigmushrooms_ = pygame.sprite.RenderPlain(BigMushroom(785,1200),BigMushroom(785,1200),BigMushroom(785,1200),BigMushroom(785,1200),bigmushroom,BigMushroom(785,5500),BigMushroom(785,5500),BigMushroom(785,5500),BigMushroom(785,5500),BigMushroom(785,5500),BigMushroom(785,5500),bigmushroom,BigMushroom(785,5500),BigMushroom(785,5500),BigMushroom(785,5500),BigMushroom(785,5500),BigMushroom(785,5500),BigMushroom(785,5500),bigmushroom,BigMushroom(785,5500),BigMushroom(785,5500),BigMushroom(785,5500),BigMushroom(785,5500),BigMushroom(785,5500),BigMushroom(785,5500),bigmushroom,BigMushroom(785,5500),BigMushroom(785,5500),BigMushroom(785,5500),BigMushroom(785,5500),BigMushroom(785,5500),BigMushroom(785,5500))
    missles_ = pygame.sprite.RenderPlain(MissleRight(-100,-745),MissleLeft(-150,-645))
    pause2=Pause(-9000,-9000)
    minion_ = pygame.sprite.RenderPlain(Minion(850,1200, bigmushroom))
    bosscat = BossCat(9000,830)
    bosscat_ = pygame.sprite.RenderPlain(bosscat)
    floor=Floor(850,0)
    floor_ = pygame.sprite.RenderPlain(floor,Platform(850,2942),Platform(850,2992),MovingPlatform(850,3100),MovingPlatform(850,4000),Floor(850,4800),Floor(850,7000),Floor(850,9000))

def main():
#Initialize Everything
    pygame.display.set_caption('Nine is not enough.')
    pygame.mouse.set_visible(0)
    
    try:
        while True:
            setup_game()
    
    #Main Loop
            global ninja
            fps = 60
            
            bInLevel = True
            while bInLevel:
                clock.tick(fps)
                if pygame.font:
                    font = pygame.font.Font(None, 36)
                    text = font.render(("   Life "+str(ninja.hp)+"    "), 1, (10, 10, 10), (255,255,255))
                    textpos = text.get_rect(centerx=background.get_width()/9)
                    background.blit(text, textpos)
    
                for event in pygame.event.get():
                    if event.type == KEYDOWN:
                        if not ninja.handle_keydown(event):
                            if event.key == K_KP_PLUS:
                                print ninja.mode
                               
                                
                            
                            pass
                    elif event.type == KEYUP:
                        if not ninja.handle_keyup(event):
                            pass
    
                for event in pygame.event.get():
                    if event.type == QUIT:
                        return
                    elif event.type == KEYDOWN and event.key == K_ESCAPE:
                        return
                    elif event.type == KEYDOWN and event.key == K_p:
                        global paused
                        paused=1
                        while paused ==1:
                            pygame.time.delay(50)
                            pause_.draw(screen)
                            pygame.display.flip()
                            for event in pygame.event.get():
                                if event.type == KEYDOWN and event.key == K_p:
                                    global paused
                                    global pause
                                    pause.kill()
                                    paused=0
                                    pause=Pause(300,300)
                                    pause_ = pygame.sprite.RenderPlain(pause)
                floor_.update()
                ninja_.update()
                bigmushrooms_.update()
                minion_.update()
                missles_.update()
                bosscat_.update()
                wall_.update()
    
    
                screen.blit(background, (0, 0))
                floor_.draw(screen)
                ninja_.draw(screen)
                bigmushrooms_.draw(screen)
                minion_.draw(screen)
                missles_.draw(screen)
                bosscat_.draw(screen)
                wall_.draw(screen)
                pygame.display.flip()
    except GameOverException: 
        pass

#this calls the 'main' function when this script is executed
instuctions = Instuctions(0,0)
instuctions_ = pygame.sprite.RenderPlain(instuctions)
instuctions_.draw(screen)
pygame.display.flip()
bkis = 0
while bkis == 0:
    pygame.time.delay(5)
    for event in pygame.event.get():
        if event.type == MOUSEBUTTONDOWN:
            bkis = 1
            instuctions.kill()
if __name__ == '__main__': main()